@@ -112,8 +112,8 @@ chown -c postgres ${BACKUP}-*.sql
 echo ""
 echo "==> Adjusting GNUmed roles ..."
 echo ""
-echo "   You will now be shown the roles backup file."
-echo "   Please edit it to only include the roles you need for GNUmed."
+echo "   You will now be shown the roles backup file. Please"
+echo "   edit it to only include the roles you need for GNUmed."
 echo ""
 echo "   Remember that in PostgreSQL scripts the comment marker is \"--\"."
 echo ""
@@ -176,6 +176,10 @@ sudo -u postgres vacuumdb -v -z -d ${TARGET_DB} -p ${GM_PORT} &> ${LOG}
 chmod 0666 ${LOG}
 
 
+# adjusting settings
+gm-adjust_db_settings.sh ${TARGET_DB}
+
+
 echo ""
 echo "==> Cleaning up ..."
 rm -vf ${WORK_DIR}/*
@@ -198,5 +202,3 @@ echo ""
 
 
 exit 0
-
-#==============================================================
