@@ -125,20 +125,26 @@ The solution is to use our own column for optimistic locking
 which gets updated by an AFTER UPDATE trigger.
 """
 #============================================================
-__version__ = "$Revision: 1.60 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
-__license__ = "GPL"
+__license__ = "GPL v2 or later"
 
-import sys, copy, types, inspect, logging, datetime
+
+import sys
+import types
+import inspect
+import logging
+import datetime
 
 
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmExceptions, gmPG2
+from Gnumed.pycommon import gmExceptions
+from Gnumed.pycommon import gmPG2
+from Gnumed.pycommon.gmDateTime import pydt_strftime
+from Gnumed.pycommon.gmTools import tex_escape_string, xetex_escape_string
 
 
 _log = logging.getLogger('gm.db')
-_log.info(__version__)
 #============================================================
 class cBusinessDBObject(object):
 	"""Represents business objects in the database.
@@ -164,11 +170,17 @@ class cBusinessDBObject(object):
 		  of their underlying tables
 
 	<_cmds_store_payload>
-		- one or multiple "update ... set ... where xmin_* = ..." statements
-		  which actually update the database from the data in self._payload,
+		- one or multiple "update ... set ... where xmin_* = ... and pk* = ..."
+		  statements which actually update the database from the data in self._payload,
 		- the last query must refetch at least the XMIN values needed to detect
 		  concurrent updates, their field names had better be the same as
 		  in _cmd_fetch_payload,
+		- the last query CAN return other fields which is particularly
+		  useful when those other fields are computed in the backend
+		  and may thus change upon save but will not have been set by
+		  the client code explicitely - this is only really of concern
+		  if the saved subclass is to be reused after saving rather
+		  than re-instantiated
 		- when subclasses tend to live a while after save_payload() was
 		  called and they support computed fields (say, _(some_column)
 		  you need to return *all* columns (see cEncounter)
@@ -188,36 +200,45 @@ from Gnumed.pycommon import gmPG2
 #============================================================
 # short description
 #------------------------------------------------------------
+# search/replace "" " -> 3 "s
+#
 # use plural form, search-replace get_XXX
-_SQL_get_XXX = u\"""
+_SQL_get_XXX = u"" "
 	SELECT *, (xmin AS xmin_XXX)
 	FROM XXX.v_XXX
 	WHERE %s
-\"""
+"" "
 
 class cXxxXxx(gmBusinessDBObject.cBusinessDBObject):
-	\"""Represents ...\"""
+	"" "Represents ..."" "
 
 	_cmd_fetch_payload = _SQL_get_XXX % u"pk_XXX = %s"
 	_cmds_store_payload = [
-		u\"""
-			UPDATE xxx.xxx SET								-- typically the underlying table name
-				xxx = %(xxx)s,								-- typically "table_col = %(view_col)s"
+		u"" "
+			-- typically the underlying table name
+			UPDATE xxx.xxx SET
+				-- typically "table_col = %(view_col)s"
+				xxx = %(xxx)s,
 				xxx = gm.nullify_empty_string(%(xxx)s)
 			WHERE
 				pk = %(pk_XXX)s
 					AND
 				xmin = %(xmin_XXX)s
 			RETURNING
-				pk as pk_XXX,
 				xmin as xmin_XXX
-		\"""
+				--, ...
+				--, ...
+		"" "
 	]
 	# view columns that can be updated:
 	_updatable_fields = [
 		u'xxx',
 		u'xxx'
 	]
+	#--------------------------------------------------------
+#	def format(self):
+#		return u'%s' % self
+
 #------------------------------------------------------------
 def get_XXX(order_by=None):
 	if order_by is None:
@@ -227,7 +248,7 @@ def get_XXX(order_by=None):
 
 	cmd = _SQL_get_XXX % order_by
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx = True)
-	return [ cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'xxx'}) for r in rows ]
+	return [ cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'pk_xxx'}) for r in rows ]
 #------------------------------------------------------------
 def create_xxx(xxx=None, xxx=None):
 
@@ -235,7 +256,7 @@ def create_xxx(xxx=None, xxx=None):
 		u'xxx': xxx,
 		u'xxx': xxx
 	}
-	cmd = u\"""
+	cmd = u"" "
 		INSERT INTO xxx.xxx (
 			xxx,
 			xxx,
@@ -246,13 +267,16 @@ def create_xxx(xxx=None, xxx=None):
 			gm.nullify_empty_string(%(xxx)s)
 		)
 		RETURNING pk
-	\"""
+		--RETURNING *
+	"" "
 	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True, get_col_idx = False)
+	#rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True, get_col_idx = True)
 
 	return cXxxXxx(aPK_obj = rows[0]['pk'])
+	#return cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'pk_XXX'})
 #------------------------------------------------------------
-def delete_xxx(xxx=None):
-	args = {'pk': xxx}
+def delete_xxx(pk_xxx=None):
+	args = {'pk': pk_xxx}
 	cmd = u"DELETE FROM xxx.xxx WHERE pk = %(pk)s"
 	gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
 	return True
@@ -356,10 +380,23 @@ def delete_xxx(xxx=None):
 		try:
 			for attr in self._idx.keys():
 				if self._payload[self._idx[attr]] is None:
-					tmp.append(u'%s: NULL' % attr)
+					tmp.append('%s: NULL' % attr)
 				else:
 					tmp.append('%s: >>%s<<' % (attr, self._payload[self._idx[attr]]))
 			return '[%s:%s]: %s' % (self.__class__.__name__, self.pk_obj, str(tmp))
+			#return '[%s:%s]:\n %s' % (self.__class__.__name__, self.pk_obj, '\n '.join(lines))
+		except:
+			return 'nascent [%s @ %s], cannot show payload and primary key' %(self.__class__.__name__, id(self))
+	#--------------------------------------------------------
+	def __unicode__(self):
+		lines = []
+		try:
+			for attr in self._idx.keys():
+				if self._payload[self._idx[attr]] is None:
+					lines.append(u'%s: NULL' % attr)
+				else:
+					lines.append('%s: %s' % (attr, self._payload[self._idx[attr]]))
+			return '[%s:%s]:\n%s' % (self.__class__.__name__, self.pk_obj, u'\n'.join(lines))
 		except:
 			return 'nascent [%s @ %s], cannot show payload and primary key' %(self.__class__.__name__, id(self))
 	#--------------------------------------------------------
@@ -441,10 +478,55 @@ def delete_xxx(xxx=None):
 	def get_updatable_fields(self):
 		return self.__class__._updatable_fields
 	#--------------------------------------------------------
+	def fields_as_dict(self, date_format='%Y %b %d  %H:%M', none_string=u'', escape_style=None, bool_strings=None):
+		if bool_strings is None:
+			bools = {True: u'true', False: u'false'}
+		else:
+			bools = {True: bool_strings[0], False: bool_strings[1]}
+		data = {}
+		for field in self._idx.keys():
+			# FIXME: harden against BYTEA fields
+			#if type(self._payload[self._idx[field]]) == ...
+			#	data[field] = _('<%s bytes of binary data>') % len(self._payload[self._idx[field]])
+			#	continue
+			val = self._payload[self._idx[field]]
+			if val is None:
+				data[field] = none_string
+				continue
+			if isinstance(val, bool):
+				data[field] = bools[val]
+				continue
+
+			if isinstance(val, datetime.datetime):
+				data[field] = pydt_strftime(val, format = date_format, encoding = 'utf8')
+				if escape_style in [u'latex', u'tex']:
+					data[field] = tex_escape_string(data[field])
+				elif escape_style in [u'xetex', u'xelatex']:
+					data[field] = xetex_escape_string(data[field])
+				continue
+
+			try:
+				data[field] = unicode(val, encoding = 'utf8', errors = 'replace')
+			except TypeError:
+				try:
+					data[field] = unicode(val)
+				except (UnicodeDecodeError, TypeError):
+					val = '%s' % str(val)
+					data[field] = val.decode('utf8', 'replace')
+			if escape_style in [u'latex', u'tex']:
+				data[field] = tex_escape_string(data[field])
+			elif escape_style in [u'xetex', u'xelatex']:
+				data[field] = xetex_escape_string(data[field])
+
+		return data
+	#--------------------------------------------------------
 	def get_patient(self):
 		_log.error('[%s:%s]: forgot to override get_patient()' % (self.__class__.__name__, self.pk_obj))
 		return None
 	#--------------------------------------------------------
+	def format(self):
+		return u'%s' % self
+	#--------------------------------------------------------
 	def refetch_payload(self, ignore_changes=False):
 		"""Fetch field values from backend.
 		"""
@@ -500,11 +582,6 @@ def delete_xxx(xxx=None):
 			conn = gmPG2.get_connection(readonly=False)
 			close_conn = conn.close
 
-		# query succeeded but failed to find the row to lock
-		# because another transaction committed an UPDATE or
-		# DELETE *before* we attempted to lock it ...
-		# FIXME: this can fail if savepoints are used since subtransactions change the xmin/xmax ...
-
 		queries = []
 		for query in self.__class__._cmds_store_payload:
 			queries.append({'cmd': query, 'args': args})
@@ -517,12 +594,16 @@ def delete_xxx(xxx=None):
 
 		# this can happen if:
 		# - someone else updated the row so XMIN does not match anymore
-		# - the PK went away (rows was deleted from under us)
+		# - the PK went away (rows were deleted from under us)
 		# - another WHERE condition of the UPDATE did not produce any rows to update
+		# - savepoints are used since subtransactions may relevantly change the xmin/xmax ...
 		if len(rows) == 0:
 			return (False, (u'cannot update row', _('[%s:%s]: row not updated (nothing returned), row in use ?') % (self.__class__.__name__, self.pk_obj)))
 
-		# update cached XMIN values (should be in first-and-only result row of last query)
+		# update cached values from should-be-first-and-only result
+		# row of last query,
+		# update all fields returned such that computed
+		# columns see their new values
 		row = rows[0]
 		for key in idx:
 			try:
@@ -642,12 +723,13 @@ if __name__ == '__main__':
 
 	data = {
 		'pk_field': 'bogus_pk',
-		'idx': {'bogus_pk': 0, 'bogus_field': 1},
-		'data': [-1, 'bogus_data']
+		'idx': {'bogus_pk': 0, 'bogus_field': 1, 'bogus_date': 2},
+		'data': [-1, 'bogus_data', datetime.datetime.now()]
 	}
 	obj = cTestObj(row=data)
 	#print obj['wrong_field']
 	#print jsonclasshintify(obj)
-	obj['wrong_field'] = 1
+	#obj['wrong_field'] = 1
+	print obj.fields_as_dict()
 
 #============================================================
