@@ -17,12 +17,11 @@ applicability by the constraints "workplace", "user", and "cookie".
 The basic API for handling items is get()/set().
 The database config objects auto-sync with the backend.
 
-@copyright: GPL
+@copyright: GPL v2 or later
 """
 # TODO:
 # - optional arg for set -> type
 #==================================================================
-__version__ = "$Revision: 1.60 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 # standard modules
@@ -36,7 +35,6 @@ from Gnumed.pycommon import gmPG2, gmTools
 
 
 _log = logging.getLogger('gm.cfg')
-_log.info(__version__)
 
 # don't change this without knowing what you do as
 # it will already be in many databases
@@ -56,7 +54,8 @@ SELECT
 	vco.*,
 	cs.value
 FROM
-	cfg.v_cfg_options vco JOIN cfg.cfg_string cs ON (vco.pk_cfg_item = cs.fk_item)
+	cfg.v_cfg_options vco
+		JOIN cfg.cfg_string cs ON (vco.pk_cfg_item = cs.fk_item)
 
 UNION ALL
 
@@ -64,7 +63,8 @@ SELECT
 	vco.*,
 	cn.value::text
 FROM
-	cfg.v_cfg_options vco JOIN cfg.cfg_numeric cn ON (vco.pk_cfg_item = cn.fk_item)
+	cfg.v_cfg_options vco
+		JOIN cfg.cfg_numeric cn ON (vco.pk_cfg_item = cn.fk_item)
 
 UNION ALL
 
@@ -72,7 +72,8 @@ SELECT
 	vco.*,
 	csa.value::text
 FROM
-	cfg.v_cfg_options vco JOIN cfg.cfg_str_array csa ON (vco.pk_cfg_item = csa.fk_item)
+	cfg.v_cfg_options vco
+		JOIN cfg.cfg_str_array csa ON (vco.pk_cfg_item = csa.fk_item)
 
 UNION ALL
 
@@ -80,7 +81,8 @@ SELECT
 	vco.*,
 	cd.value::text
 FROM
-	cfg.v_cfg_options vco JOIN cfg.cfg_data cd ON (vco.pk_cfg_item = cd.fk_item)
+	cfg.v_cfg_options vco
+		JOIN cfg.cfg_data cd ON (vco.pk_cfg_item = cd.fk_item)
 
 ) as option_list
 %s""" % order_by
@@ -401,7 +403,16 @@ where %s""" % where_clause
 		rows, idx = gmPG2.run_ro_queries(link_obj=self.ro_conn, queries = [{'cmd': cmd, 'args': where_args}], return_data=True)
 		return rows
 	#----------------------------
-	def delete(self, workplace = None, cookie = None, option = None):
+	def delete(self, conn=None, pk_option=None):
+		if conn is None:
+			# without a gm-dbo connection you can only delete your own options :-)
+			cmd = u"DELETE FROM cfg.cfg_item WHERE pk = %(pk)s AND owner = CURRENT_USER"
+		else:
+			cmd = u"DELETE FROM cfg.cfg_item WHERE pk = %(pk)s"
+		args = {'pk': pk_option}
+		gmPG2.run_rw_queries(link_obj = conn, queries = [{'cmd': cmd, 'args': args}], end_tx = True)
+	#----------------------------
+	def delete_old(self, workplace = None, cookie = None, option = None):
 		"""
 		Deletes an option or a whole group.
 		Note you have to call store() in order to save
