@@ -17,20 +17,22 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.4.4 (database v19.4)',
-	'GNUmed 1.4.4 Release Notes:
+	'Release Notes for GNUmed 1.4.6 (database v19.6)',
+	'GNUmed 1.4.6 Release Notes:
 
-	1.4.4
+	1.4.6
 
-FIX: gracefully recover from invalid URLs [thanks Jim]
-FIX: encounter editing from EMR browser [thanks Jim]
-FIX: faulty date access in test result EA [thanks Jim]
-FIX: a few minor bugs displaying test results
+FIX: missing qualification of make_pg_exception_fields_unicode() [thanks Khalil]
+FIX: missing method in TimeLine code
+FIX: bug in new-person EA validation code
+FIX: creating dummy identities used faulty gender
+FIX: faulty apparent_age formatting (age between 1-2 month ignored)
+FIX: attempt to use "chart review" encounter type even if it does not exist [thanks Jim]
 
-IMPROVED: results formatting in episode synopsis of EMR tree
-IMPROVED: lots of details in the test results grid
+IMPROVED: DOB/age display in top panel
+IMPROVED: deal with display of missing gender
 
-	19.4 -- Requires PostgreSQL 9.1 !
+	19.6 -- Requires PostgreSQL 9.1 !
 ');
 
 -- --------------------------------------------------------------
